3 ms·
numpy, for comparison: In [8]: vec = np.random.randint(-200, 200, (100_000_000,)) In [9]: %timeit vec.sum() 63 ms ± 4.81 ms per loop (mean ± std. dev
by orf 6y ago
numpy, for comparison:
In [8]: vec = np.random.randint(-200, 200, (100_000_000,))
In [9]: %timeit vec.sum()
63 ms ± 4.81 ms per loop (mean ± std. dev. of 7 runs, 10 loops each)
The branchless C++ version took 125ms, and the AVX 512 version took ~9ms.